[![codecov](https://codecov.io/gh/ad12/MedSegPy/branch/master/graph/badge.svg?token=GKSGMGAY6C)](https://codecov.io/gh/ad12/MedSegPy)

# MedSegPy
MedSegPy is a medical segmentation framework that implements state-of-the-art semantic segmentation algorithms. It is designed to utilize the Keras/Tensorflow libraries and make training easily configurable.

## Installation

See [INSTALL.md](INSTALL.md).

## Quick Start

See [GETTING_STARTED.md](GETTING_STARTED.md) and learn more at our 
[documentation](https://ad12.github.io/MedSegPy/_build/html/index.html).


## How To Cite
```
@article{desai2019technical,
  title={Technical considerations for semantic segmentation in MRI using convolutional neural networks},
  author={Desai, Arjun D and Gold, Garry E and Hargreaves, Brian A and Chaudhari, Akshay S},
  journal={arXiv preprint arXiv:1902.01977},
  year={2019}
}
```
